Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(62)

Unified Diff: runtime/vm/raw_object.h

Issue 17421003: Store arguments descriptor in ICData. Remove loading of arguments descriptor at unoptimized call si… (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/parser.h ('k') | runtime/vm/stub_code_arm.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/raw_object.h
===================================================================
--- runtime/vm/raw_object.h (revision 24207)
+++ runtime/vm/raw_object.h (working copy)
@@ -1022,16 +1022,17 @@
RawObject** from() {
return reinterpret_cast<RawObject**>(&ptr()->function_);
}
- RawFunction* function_; // Parent/calling function of this IC.
- RawString* target_name_; // Name of target function.
- RawArray* ic_data_; // Contains test class-ids and target functions.
+ RawFunction* function_; // Parent/calling function of this IC.
+ RawString* target_name_; // Name of target function.
+ RawArray* args_descriptor_; // Arguments descriptor.
+ RawArray* ic_data_; // Contains test class-ids and target functions.
RawObject** to() {
return reinterpret_cast<RawObject**>(&ptr()->ic_data_);
}
- intptr_t deopt_id_; // Deoptimization id corresponding to this IC.
- intptr_t num_args_tested_; // Number of arguments tested in IC.
- uint8_t deopt_reason_; // Last deoptimization reason.
- uint8_t is_closure_call_; // 0 or 1.
+ intptr_t deopt_id_; // Deoptimization id corresponding to this IC.
+ intptr_t num_args_tested_; // Number of arguments tested in IC.
+ uint8_t deopt_reason_; // Last deoptimization reason.
+ uint8_t is_closure_call_; // 0 or 1.
};
« no previous file with comments | « runtime/vm/parser.h ('k') | runtime/vm/stub_code_arm.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698